# [#13] Support Jira issues

I would like to support both github or jira. 

- Issues should be limited to a project 
- Epic/tasks/subtask should be supported by a metadata key ":parent:"

# [#12] setup travis CI

:milestone: sprint1
:labels: infrastructure
:assignee: mgaitan
:state: closed

# [#11] support metadata

- labels
- milestone
- assigned to
- created/updated dates

:state: closed
